CSS Stylesheet — CubicWeb 3.13.2

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »
- Web side development »

# CSS Stylesheet

## Conventions

## Extending / overriding existing styles

We cannot modify the order in which the application is reading the CSS. In the case we want to create new CSS style, the best is to define it a in a new CSS located under `myapp/data/` and use those new styles while writing customized views and templates.

If you want to modify an existing CSS styling property, you will have to use `!important` declaration to override the existing property. The application apply a higher priority on the default CSS and you can not change that. Customized CSS will not be read first.

## CubicWeb stylesheets

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »
- Web side development »